"""SpeedTorqueCurveLoadCase"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private.electric_machines.load_cases_and_analyses import _1413
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_SPEED_TORQUE_CURVE_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses", "SpeedTorqueCurveLoadCase"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.electric_machines import _1308
    from mastapy._private.electric_machines.load_cases_and_analyses import _1420, _1405

    Self = TypeVar("Self", bound="SpeedTorqueCurveLoadCase")
    CastSelf = TypeVar(
        "CastSelf", bound="SpeedTorqueCurveLoadCase._Cast_SpeedTorqueCurveLoadCase"
    )


__docformat__ = "restructuredtext en"
__all__ = ("SpeedTorqueCurveLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpeedTorqueCurveLoadCase:
    """Special nested class for casting SpeedTorqueCurveLoadCase to subclasses."""

    __parent__: "SpeedTorqueCurveLoadCase"

    @property
    def non_linear_dq_model_multiple_operating_points_load_case(
        self: "CastSelf",
    ) -> "_1413.NonLinearDQModelMultipleOperatingPointsLoadCase":
        return self.__parent__._cast(
            _1413.NonLinearDQModelMultipleOperatingPointsLoadCase
        )

    @property
    def electric_machine_load_case_base(
        self: "CastSelf",
    ) -> "_1405.ElectricMachineLoadCaseBase":
        from mastapy._private.electric_machines.load_cases_and_analyses import _1405

        return self.__parent__._cast(_1405.ElectricMachineLoadCaseBase)

    @property
    def speed_torque_curve_load_case(self: "CastSelf") -> "SpeedTorqueCurveLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class SpeedTorqueCurveLoadCase(_1413.NonLinearDQModelMultipleOperatingPointsLoadCase):
    """SpeedTorqueCurveLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPEED_TORQUE_CURVE_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def maximum_speed(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MaximumSpeed

        if temp is None:
            return 0.0

        return temp

    @maximum_speed.setter
    @enforce_parameter_types
    def maximum_speed(self: "Self", value: "float") -> None:
        self.wrapped.MaximumSpeed = float(value) if value is not None else 0.0

    @property
    def minimum_speed(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MinimumSpeed

        if temp is None:
            return 0.0

        return temp

    @minimum_speed.setter
    @enforce_parameter_types
    def minimum_speed(self: "Self", value: "float") -> None:
        self.wrapped.MinimumSpeed = float(value) if value is not None else 0.0

    @property
    def number_of_speed_values(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.NumberOfSpeedValues

        if temp is None:
            return 0

        return temp

    @number_of_speed_values.setter
    @enforce_parameter_types
    def number_of_speed_values(self: "Self", value: "int") -> None:
        self.wrapped.NumberOfSpeedValues = int(value) if value is not None else 0

    @enforce_parameter_types
    def analysis_for(
        self: "Self", setup: "_1308.ElectricMachineSetup"
    ) -> "_1420.SpeedTorqueCurveAnalysis":
        """mastapy._private.electric_machines.load_cases_and_analyses.SpeedTorqueCurveAnalysis

        Args:
            setup (mastapy._private.electric_machines.ElectricMachineSetup)
        """
        method_result = self.wrapped.AnalysisFor(setup.wrapped if setup else None)
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @property
    def cast_to(self: "Self") -> "_Cast_SpeedTorqueCurveLoadCase":
        """Cast to another type.

        Returns:
            _Cast_SpeedTorqueCurveLoadCase
        """
        return _Cast_SpeedTorqueCurveLoadCase(self)



"""TorqueConverterPumpSocket"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.system_model.connections_and_sockets.couplings import _2400
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_TORQUE_CONVERTER_PUMP_SOCKET = python_net_import(
    "SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Couplings",
    "TorqueConverterPumpSocket",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.connections_and_sockets import _2329, _2349

    Self = TypeVar("Self", bound="TorqueConverterPumpSocket")
    CastSelf = TypeVar(
        "CastSelf", bound="TorqueConverterPumpSocket._Cast_TorqueConverterPumpSocket"
    )


__docformat__ = "restructuredtext en"
__all__ = ("TorqueConverterPumpSocket",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TorqueConverterPumpSocket:
    """Special nested class for casting TorqueConverterPumpSocket to subclasses."""

    __parent__: "TorqueConverterPumpSocket"

    @property
    def coupling_socket(self: "CastSelf") -> "_2400.CouplingSocket":
        return self.__parent__._cast(_2400.CouplingSocket)

    @property
    def cylindrical_socket(self: "CastSelf") -> "_2329.CylindricalSocket":
        from mastapy._private.system_model.connections_and_sockets import _2329

        return self.__parent__._cast(_2329.CylindricalSocket)

    @property
    def socket(self: "CastSelf") -> "_2349.Socket":
        from mastapy._private.system_model.connections_and_sockets import _2349

        return self.__parent__._cast(_2349.Socket)

    @property
    def torque_converter_pump_socket(self: "CastSelf") -> "TorqueConverterPumpSocket":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class TorqueConverterPumpSocket(_2400.CouplingSocket):
    """TorqueConverterPumpSocket

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TORQUE_CONVERTER_PUMP_SOCKET

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_TorqueConverterPumpSocket":
        """Cast to another type.

        Returns:
            _Cast_TorqueConverterPumpSocket
        """
        return _Cast_TorqueConverterPumpSocket(self)



"""RelativeOffsetOption"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_RELATIVE_OFFSET_OPTION = python_net_import(
    "SMT.MastaAPI.SystemModel", "RelativeOffsetOption"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="RelativeOffsetOption")
    CastSelf = TypeVar(
        "CastSelf", bound="RelativeOffsetOption._Cast_RelativeOffsetOption"
    )


__docformat__ = "restructuredtext en"
__all__ = ("RelativeOffsetOption",)


class RelativeOffsetOption(Enum):
    """RelativeOffsetOption

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _RELATIVE_OFFSET_OPTION

    LEFT = 0
    CENTRE = 1
    RIGHT = 2
    SPECIFIED = 3


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


RelativeOffsetOption.__setattr__ = __enum_setattr
RelativeOffsetOption.__delattr__ = __enum_delattr



"""CylindricalMeshManufacturingConfig"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.gears.analysis import _1263
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_MESH_MANUFACTURING_CONFIG = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical", "CylindricalMeshManufacturingConfig"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.gears.manufacturing.cylindrical.cutter_simulation import (
        _754,
        _757,
        _758,
    )
    from mastapy._private.gears.analysis import _1260, _1254

    Self = TypeVar("Self", bound="CylindricalMeshManufacturingConfig")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalMeshManufacturingConfig._Cast_CylindricalMeshManufacturingConfig",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalMeshManufacturingConfig",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalMeshManufacturingConfig:
    """Special nested class for casting CylindricalMeshManufacturingConfig to subclasses."""

    __parent__: "CylindricalMeshManufacturingConfig"

    @property
    def gear_mesh_implementation_detail(
        self: "CastSelf",
    ) -> "_1263.GearMeshImplementationDetail":
        return self.__parent__._cast(_1263.GearMeshImplementationDetail)

    @property
    def gear_mesh_design_analysis(self: "CastSelf") -> "_1260.GearMeshDesignAnalysis":
        from mastapy._private.gears.analysis import _1260

        return self.__parent__._cast(_1260.GearMeshDesignAnalysis)

    @property
    def abstract_gear_mesh_analysis(
        self: "CastSelf",
    ) -> "_1254.AbstractGearMeshAnalysis":
        from mastapy._private.gears.analysis import _1254

        return self.__parent__._cast(_1254.AbstractGearMeshAnalysis)

    @property
    def cylindrical_mesh_manufacturing_config(
        self: "CastSelf",
    ) -> "CylindricalMeshManufacturingConfig":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalMeshManufacturingConfig(_1263.GearMeshImplementationDetail):
    """CylindricalMeshManufacturingConfig

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_MESH_MANUFACTURING_CONFIG

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def gear_a_as_manufactured(self: "Self") -> "List[_754.CutterSimulationCalc]":
        """List[mastapy._private.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearAAsManufactured

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def gear_b_as_manufactured(self: "Self") -> "List[_754.CutterSimulationCalc]":
        """List[mastapy._private.gears.manufacturing.cylindrical.cutter_simulation.CutterSimulationCalc]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearBAsManufactured

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def meshed_gear_a_as_manufactured(
        self: "Self",
    ) -> "List[_757.CylindricalManufacturedRealGearInMesh]":
        """List[mastapy._private.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedRealGearInMesh]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshedGearAAsManufactured

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def meshed_gear_a_as_manufactured_virtual(
        self: "Self",
    ) -> "List[_758.CylindricalManufacturedVirtualGearInMesh]":
        """List[mastapy._private.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshedGearAAsManufacturedVirtual

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def meshed_gear_b_as_manufactured(
        self: "Self",
    ) -> "List[_757.CylindricalManufacturedRealGearInMesh]":
        """List[mastapy._private.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedRealGearInMesh]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshedGearBAsManufactured

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def meshed_gear_b_as_manufactured_virtual(
        self: "Self",
    ) -> "List[_758.CylindricalManufacturedVirtualGearInMesh]":
        """List[mastapy._private.gears.manufacturing.cylindrical.cutter_simulation.CylindricalManufacturedVirtualGearInMesh]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshedGearBAsManufacturedVirtual

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalMeshManufacturingConfig":
        """Cast to another type.

        Returns:
            _Cast_CylindricalMeshManufacturingConfig
        """
        return _Cast_CylindricalMeshManufacturingConfig(self)



"""Gear"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.part_model import _2520
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GEAR = python_net_import("SMT.MastaAPI.SystemModel.PartModel.Gears", "Gear")

if TYPE_CHECKING:
    from typing import Any, Type, Optional, TypeVar

    from mastapy._private.gears.gear_designs import _971
    from mastapy._private.system_model.part_model.gears import (
        _2588,
        _2569,
        _2571,
        _2573,
        _2574,
        _2575,
        _2577,
        _2579,
        _2581,
        _2583,
        _2584,
        _2590,
        _2592,
        _2594,
        _2596,
        _2599,
        _2601,
        _2603,
        _2605,
        _2606,
        _2607,
        _2609,
    )
    from mastapy._private.system_model.part_model.shaft_model import _2538
    from mastapy._private.system_model.part_model import _2498, _2524
    from mastapy._private.system_model import _2256

    Self = TypeVar("Self", bound="Gear")
    CastSelf = TypeVar("CastSelf", bound="Gear._Cast_Gear")


__docformat__ = "restructuredtext en"
__all__ = ("Gear",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Gear:
    """Special nested class for casting Gear to subclasses."""

    __parent__: "Gear"

    @property
    def mountable_component(self: "CastSelf") -> "_2520.MountableComponent":
        return self.__parent__._cast(_2520.MountableComponent)

    @property
    def component(self: "CastSelf") -> "_2498.Component":
        from mastapy._private.system_model.part_model import _2498

        return self.__parent__._cast(_2498.Component)

    @property
    def part(self: "CastSelf") -> "_2524.Part":
        from mastapy._private.system_model.part_model import _2524

        return self.__parent__._cast(_2524.Part)

    @property
    def design_entity(self: "CastSelf") -> "_2256.DesignEntity":
        from mastapy._private.system_model import _2256

        return self.__parent__._cast(_2256.DesignEntity)

    @property
    def agma_gleason_conical_gear(self: "CastSelf") -> "_2569.AGMAGleasonConicalGear":
        from mastapy._private.system_model.part_model.gears import _2569

        return self.__parent__._cast(_2569.AGMAGleasonConicalGear)

    @property
    def bevel_differential_gear(self: "CastSelf") -> "_2571.BevelDifferentialGear":
        from mastapy._private.system_model.part_model.gears import _2571

        return self.__parent__._cast(_2571.BevelDifferentialGear)

    @property
    def bevel_differential_planet_gear(
        self: "CastSelf",
    ) -> "_2573.BevelDifferentialPlanetGear":
        from mastapy._private.system_model.part_model.gears import _2573

        return self.__parent__._cast(_2573.BevelDifferentialPlanetGear)

    @property
    def bevel_differential_sun_gear(
        self: "CastSelf",
    ) -> "_2574.BevelDifferentialSunGear":
        from mastapy._private.system_model.part_model.gears import _2574

        return self.__parent__._cast(_2574.BevelDifferentialSunGear)

    @property
    def bevel_gear(self: "CastSelf") -> "_2575.BevelGear":
        from mastapy._private.system_model.part_model.gears import _2575

        return self.__parent__._cast(_2575.BevelGear)

    @property
    def concept_gear(self: "CastSelf") -> "_2577.ConceptGear":
        from mastapy._private.system_model.part_model.gears import _2577

        return self.__parent__._cast(_2577.ConceptGear)

    @property
    def conical_gear(self: "CastSelf") -> "_2579.ConicalGear":
        from mastapy._private.system_model.part_model.gears import _2579

        return self.__parent__._cast(_2579.ConicalGear)

    @property
    def cylindrical_gear(self: "CastSelf") -> "_2581.CylindricalGear":
        from mastapy._private.system_model.part_model.gears import _2581

        return self.__parent__._cast(_2581.CylindricalGear)

    @property
    def cylindrical_planet_gear(self: "CastSelf") -> "_2583.CylindricalPlanetGear":
        from mastapy._private.system_model.part_model.gears import _2583

        return self.__parent__._cast(_2583.CylindricalPlanetGear)

    @property
    def face_gear(self: "CastSelf") -> "_2584.FaceGear":
        from mastapy._private.system_model.part_model.gears import _2584

        return self.__parent__._cast(_2584.FaceGear)

    @property
    def hypoid_gear(self: "CastSelf") -> "_2590.HypoidGear":
        from mastapy._private.system_model.part_model.gears import _2590

        return self.__parent__._cast(_2590.HypoidGear)

    @property
    def klingelnberg_cyclo_palloid_conical_gear(
        self: "CastSelf",
    ) -> "_2592.KlingelnbergCycloPalloidConicalGear":
        from mastapy._private.system_model.part_model.gears import _2592

        return self.__parent__._cast(_2592.KlingelnbergCycloPalloidConicalGear)

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear(
        self: "CastSelf",
    ) -> "_2594.KlingelnbergCycloPalloidHypoidGear":
        from mastapy._private.system_model.part_model.gears import _2594

        return self.__parent__._cast(_2594.KlingelnbergCycloPalloidHypoidGear)

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear(
        self: "CastSelf",
    ) -> "_2596.KlingelnbergCycloPalloidSpiralBevelGear":
        from mastapy._private.system_model.part_model.gears import _2596

        return self.__parent__._cast(_2596.KlingelnbergCycloPalloidSpiralBevelGear)

    @property
    def spiral_bevel_gear(self: "CastSelf") -> "_2599.SpiralBevelGear":
        from mastapy._private.system_model.part_model.gears import _2599

        return self.__parent__._cast(_2599.SpiralBevelGear)

    @property
    def straight_bevel_diff_gear(self: "CastSelf") -> "_2601.StraightBevelDiffGear":
        from mastapy._private.system_model.part_model.gears import _2601

        return self.__parent__._cast(_2601.StraightBevelDiffGear)

    @property
    def straight_bevel_gear(self: "CastSelf") -> "_2603.StraightBevelGear":
        from mastapy._private.system_model.part_model.gears import _2603

        return self.__parent__._cast(_2603.StraightBevelGear)

    @property
    def straight_bevel_planet_gear(self: "CastSelf") -> "_2605.StraightBevelPlanetGear":
        from mastapy._private.system_model.part_model.gears import _2605

        return self.__parent__._cast(_2605.StraightBevelPlanetGear)

    @property
    def straight_bevel_sun_gear(self: "CastSelf") -> "_2606.StraightBevelSunGear":
        from mastapy._private.system_model.part_model.gears import _2606

        return self.__parent__._cast(_2606.StraightBevelSunGear)

    @property
    def worm_gear(self: "CastSelf") -> "_2607.WormGear":
        from mastapy._private.system_model.part_model.gears import _2607

        return self.__parent__._cast(_2607.WormGear)

    @property
    def zerol_bevel_gear(self: "CastSelf") -> "_2609.ZerolBevelGear":
        from mastapy._private.system_model.part_model.gears import _2609

        return self.__parent__._cast(_2609.ZerolBevelGear)

    @property
    def gear(self: "CastSelf") -> "Gear":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class Gear(_2520.MountableComponent):
    """Gear

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _GEAR

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cloned_from(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ClonedFrom

        if temp is None:
            return ""

        return temp

    @property
    def even_number_of_teeth_required(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.EvenNumberOfTeethRequired

        if temp is None:
            return False

        return temp

    @even_number_of_teeth_required.setter
    @enforce_parameter_types
    def even_number_of_teeth_required(self: "Self", value: "bool") -> None:
        self.wrapped.EvenNumberOfTeethRequired = (
            bool(value) if value is not None else False
        )

    @property
    def is_clone_gear(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IsCloneGear

        if temp is None:
            return False

        return temp

    @property
    def length(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.Length

        if temp is None:
            return 0.0

        return temp

    @length.setter
    @enforce_parameter_types
    def length(self: "Self", value: "float") -> None:
        self.wrapped.Length = float(value) if value is not None else 0.0

    @property
    def maximum_number_of_teeth(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.MaximumNumberOfTeeth

        if temp is None:
            return 0

        return temp

    @maximum_number_of_teeth.setter
    @enforce_parameter_types
    def maximum_number_of_teeth(self: "Self", value: "int") -> None:
        self.wrapped.MaximumNumberOfTeeth = int(value) if value is not None else 0

    @property
    def maximum_and_minimum_number_of_teeth_deviation(self: "Self") -> "Optional[int]":
        """Optional[int]"""
        temp = self.wrapped.MaximumAndMinimumNumberOfTeethDeviation

        if temp is None:
            return None

        return temp

    @maximum_and_minimum_number_of_teeth_deviation.setter
    @enforce_parameter_types
    def maximum_and_minimum_number_of_teeth_deviation(
        self: "Self", value: "Optional[int]"
    ) -> None:
        self.wrapped.MaximumAndMinimumNumberOfTeethDeviation = value

    @property
    def minimum_number_of_teeth(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.MinimumNumberOfTeeth

        if temp is None:
            return 0

        return temp

    @minimum_number_of_teeth.setter
    @enforce_parameter_types
    def minimum_number_of_teeth(self: "Self", value: "int") -> None:
        self.wrapped.MinimumNumberOfTeeth = int(value) if value is not None else 0

    @property
    def active_gear_design(self: "Self") -> "_971.GearDesign":
        """mastapy._private.gears.gear_designs.GearDesign

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ActiveGearDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def face_width(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceWidth

        if temp is None:
            return 0.0

        return temp

    @face_width.setter
    @enforce_parameter_types
    def face_width(self: "Self", value: "float") -> None:
        self.wrapped.FaceWidth = float(value) if value is not None else 0.0

    @property
    def gear_set(self: "Self") -> "_2588.GearSet":
        """mastapy._private.system_model.part_model.gears.GearSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearSet

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def number_of_teeth(self: "Self") -> "int":
        """int"""
        temp = self.wrapped.NumberOfTeeth

        if temp is None:
            return 0

        return temp

    @number_of_teeth.setter
    @enforce_parameter_types
    def number_of_teeth(self: "Self", value: "int") -> None:
        self.wrapped.NumberOfTeeth = int(value) if value is not None else 0

    @property
    def shaft(self: "Self") -> "_2538.Shaft":
        """mastapy._private.system_model.part_model.shaft_model.Shaft

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Shaft

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @enforce_parameter_types
    def connect_to(self: "Self", other_gear: "Gear") -> None:
        """Method does not return.

        Args:
            other_gear (mastapy._private.system_model.part_model.gears.Gear)
        """
        self.wrapped.ConnectTo(other_gear.wrapped if other_gear else None)

    @property
    def cast_to(self: "Self") -> "_Cast_Gear":
        """Cast to another type.

        Returns:
            _Cast_Gear
        """
        return _Cast_Gear(self)



"""MethodOutcomeWithResult"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.utility import _1637
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_METHOD_OUTCOME_WITH_RESULT = python_net_import(
    "SMT.MastaAPI.Utility", "MethodOutcomeWithResult"
)

if TYPE_CHECKING:
    from typing import Any, Type

    Self = TypeVar("Self", bound="MethodOutcomeWithResult")
    CastSelf = TypeVar(
        "CastSelf", bound="MethodOutcomeWithResult._Cast_MethodOutcomeWithResult"
    )

T = TypeVar("T")

__docformat__ = "restructuredtext en"
__all__ = ("MethodOutcomeWithResult",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_MethodOutcomeWithResult:
    """Special nested class for casting MethodOutcomeWithResult to subclasses."""

    __parent__: "MethodOutcomeWithResult"

    @property
    def method_outcome(self: "CastSelf") -> "_1637.MethodOutcome":
        return self.__parent__._cast(_1637.MethodOutcome)

    @property
    def method_outcome_with_result(self: "CastSelf") -> "MethodOutcomeWithResult":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class MethodOutcomeWithResult(_1637.MethodOutcome, Generic[T]):
    """MethodOutcomeWithResult

    This is a mastapy class.

    Generic Types:
        T
    """

    TYPE: ClassVar["Type"] = _METHOD_OUTCOME_WITH_RESULT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def result(self: "Self") -> "T":
        """T

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Result

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_MethodOutcomeWithResult":
        """Cast to another type.

        Returns:
            _Cast_MethodOutcomeWithResult
        """
        return _Cast_MethodOutcomeWithResult(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.nodal_analysis.elmer.results._185 import Data
    from mastapy._private.nodal_analysis.elmer.results._186 import Data1D
    from mastapy._private.nodal_analysis.elmer.results._187 import Data3D
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.nodal_analysis.elmer.results._185": ["Data"],
        "_private.nodal_analysis.elmer.results._186": ["Data1D"],
        "_private.nodal_analysis.elmer.results._187": ["Data3D"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "Data",
    "Data1D",
    "Data3D",
)



"""CADToothAndSlot"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.electric_machines import _1283
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CAD_TOOTH_AND_SLOT = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "CADToothAndSlot"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.electric_machines import _1318, _1357

    Self = TypeVar("Self", bound="CADToothAndSlot")
    CastSelf = TypeVar("CastSelf", bound="CADToothAndSlot._Cast_CADToothAndSlot")


__docformat__ = "restructuredtext en"
__all__ = ("CADToothAndSlot",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CADToothAndSlot:
    """Special nested class for casting CADToothAndSlot to subclasses."""

    __parent__: "CADToothAndSlot"

    @property
    def abstract_tooth_and_slot(self: "CastSelf") -> "_1283.AbstractToothAndSlot":
        return self.__parent__._cast(_1283.AbstractToothAndSlot)

    @property
    def cad_tooth_and_slot(self: "CastSelf") -> "CADToothAndSlot":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CADToothAndSlot(_1283.AbstractToothAndSlot):
    """CADToothAndSlot

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CAD_TOOTH_AND_SLOT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def individual_conductor_specification_source(
        self: "Self",
    ) -> "_1318.IndividualConductorSpecificationSource":
        """mastapy._private.electric_machines.IndividualConductorSpecificationSource"""
        temp = self.wrapped.IndividualConductorSpecificationSource

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.ElectricMachines.IndividualConductorSpecificationSource"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.electric_machines._1318",
            "IndividualConductorSpecificationSource",
        )(value)

    @individual_conductor_specification_source.setter
    @enforce_parameter_types
    def individual_conductor_specification_source(
        self: "Self", value: "_1318.IndividualConductorSpecificationSource"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.ElectricMachines.IndividualConductorSpecificationSource",
        )
        self.wrapped.IndividualConductorSpecificationSource = value

    @property
    def conductors(self: "Self") -> "List[_1357.WindingConductor]":
        """List[mastapy._private.electric_machines.WindingConductor]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Conductors

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_CADToothAndSlot":
        """Cast to another type.

        Returns:
            _Cast_CADToothAndSlot
        """
        return _Cast_CADToothAndSlot(self)



"""AssemblyMultibodyDynamicsAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.mbd_analyses import _5499
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ASSEMBLY_MULTIBODY_DYNAMICS_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.MBDAnalyses",
    "AssemblyMultibodyDynamicsAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.part_model import _2487
    from mastapy._private.system_model.analyses_and_results.static_loads import _6965
    from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
        _5509,
        _5512,
        _5515,
        _5521,
        _5522,
        _5544,
        _5525,
        _5531,
        _5534,
        _5573,
        _5546,
        _5548,
        _5552,
        _5559,
        _5558,
        _5560,
        _5564,
        _5568,
        _5579,
        _5582,
        _5583,
        _5587,
        _5589,
        _5592,
        _5596,
        _5599,
        _5600,
        _5601,
        _5603,
        _5605,
        _5611,
        _5612,
        _5501,
        _5618,
        _5622,
        _5625,
        _5628,
        _5632,
        _5637,
        _5641,
        _5646,
        _5649,
        _5608,
        _5593,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7714,
        _7710,
    )
    from mastapy._private.system_model.analyses_and_results import _2740, _2736, _2734

    Self = TypeVar("Self", bound="AssemblyMultibodyDynamicsAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AssemblyMultibodyDynamicsAnalysis._Cast_AssemblyMultibodyDynamicsAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AssemblyMultibodyDynamicsAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AssemblyMultibodyDynamicsAnalysis:
    """Special nested class for casting AssemblyMultibodyDynamicsAnalysis to subclasses."""

    __parent__: "AssemblyMultibodyDynamicsAnalysis"

    @property
    def abstract_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5499.AbstractAssemblyMultibodyDynamicsAnalysis":
        return self.__parent__._cast(_5499.AbstractAssemblyMultibodyDynamicsAnalysis)

    @property
    def part_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5593.PartMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5593,
        )

        return self.__parent__._cast(_5593.PartMultibodyDynamicsAnalysis)

    @property
    def part_time_series_load_analysis_case(
        self: "CastSelf",
    ) -> "_7714.PartTimeSeriesLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7714,
        )

        return self.__parent__._cast(_7714.PartTimeSeriesLoadAnalysisCase)

    @property
    def part_analysis_case(self: "CastSelf") -> "_7710.PartAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7710,
        )

        return self.__parent__._cast(_7710.PartAnalysisCase)

    @property
    def part_analysis(self: "CastSelf") -> "_2740.PartAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2740

        return self.__parent__._cast(_2740.PartAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def root_assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "_5608.RootAssemblyMultibodyDynamicsAnalysis":
        from mastapy._private.system_model.analyses_and_results.mbd_analyses import (
            _5608,
        )

        return self.__parent__._cast(_5608.RootAssemblyMultibodyDynamicsAnalysis)

    @property
    def assembly_multibody_dynamics_analysis(
        self: "CastSelf",
    ) -> "AssemblyMultibodyDynamicsAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AssemblyMultibodyDynamicsAnalysis(
    _5499.AbstractAssemblyMultibodyDynamicsAnalysis
):
    """AssemblyMultibodyDynamicsAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ASSEMBLY_MULTIBODY_DYNAMICS_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def assembly_design(self: "Self") -> "_2487.Assembly":
        """mastapy._private.system_model.part_model.Assembly

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def assembly_load_case(self: "Self") -> "_6965.AssemblyLoadCase":
        """mastapy._private.system_model.analyses_and_results.static_loads.AssemblyLoadCase

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AssemblyLoadCase

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def bearings(self: "Self") -> "List[_5509.BearingMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.BearingMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bearings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def belt_drives(self: "Self") -> "List[_5512.BeltDriveMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.BeltDriveMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BeltDrives

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bevel_differential_gear_sets(
        self: "Self",
    ) -> "List[_5515.BevelDifferentialGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.BevelDifferentialGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BevelDifferentialGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolted_joints(
        self: "Self",
    ) -> "List[_5521.BoltedJointMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.BoltedJointMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BoltedJoints

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def bolts(self: "Self") -> "List[_5522.BoltMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.BoltMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Bolts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cv_ts(self: "Self") -> "List[_5544.CVTMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.CVTMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CVTs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def clutches(self: "Self") -> "List[_5525.ClutchMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ClutchMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Clutches

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_couplings(
        self: "Self",
    ) -> "List[_5531.ConceptCouplingMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ConceptCouplingMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def concept_gear_sets(
        self: "Self",
    ) -> "List[_5534.ConceptGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ConceptGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConceptGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def connections(
        self: "Self",
    ) -> "List[_5573.InterMountableComponentConnectionMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.InterMountableComponentConnectionMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Connections

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_assemblies(
        self: "Self",
    ) -> "List[_5546.CycloidalAssemblyMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.CycloidalAssemblyMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cycloidal_discs(
        self: "Self",
    ) -> "List[_5548.CycloidalDiscMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.CycloidalDiscMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CycloidalDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cylindrical_gear_sets(
        self: "Self",
    ) -> "List[_5552.CylindricalGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.CylindricalGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CylindricalGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def fe_parts(self: "Self") -> "List[_5559.FEPartMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.FEPartMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FEParts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def face_gear_sets(
        self: "Self",
    ) -> "List[_5558.FaceGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.FaceGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def flexible_pin_assemblies(
        self: "Self",
    ) -> "List[_5560.FlexiblePinAssemblyMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.FlexiblePinAssemblyMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FlexiblePinAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def gear_sets(self: "Self") -> "List[_5564.GearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.GearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def hypoid_gear_sets(
        self: "Self",
    ) -> "List[_5568.HypoidGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.HypoidGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_sets(
        self: "Self",
    ) -> "List[_5579.KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidHypoidGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_sets(
        self: "Self",
    ) -> "List[_5582.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.KlingelnbergCycloPalloidSpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def mass_discs(self: "Self") -> "List[_5583.MassDiscMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.MassDiscMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MassDiscs

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def measurement_components(
        self: "Self",
    ) -> "List[_5587.MeasurementComponentMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.MeasurementComponentMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeasurementComponents

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def microphones(self: "Self") -> "List[_5589.MicrophoneMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.MicrophoneMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Microphones

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def oil_seals(self: "Self") -> "List[_5592.OilSealMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.OilSealMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OilSeals

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def part_to_part_shear_couplings(
        self: "Self",
    ) -> "List[_5596.PartToPartShearCouplingMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.PartToPartShearCouplingMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PartToPartShearCouplings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def planet_carriers(
        self: "Self",
    ) -> "List[_5599.PlanetCarrierMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.PlanetCarrierMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PlanetCarriers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def point_loads(self: "Self") -> "List[_5600.PointLoadMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.PointLoadMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PointLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def power_loads(self: "Self") -> "List[_5601.PowerLoadMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.PowerLoadMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PowerLoads

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def ring_pins(self: "Self") -> "List[_5603.RingPinsMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.RingPinsMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RingPins

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def rolling_ring_assemblies(
        self: "Self",
    ) -> "List[_5605.RollingRingAssemblyMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.RollingRingAssemblyMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollingRingAssemblies

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shaft_hub_connections(
        self: "Self",
    ) -> "List[_5611.ShaftHubConnectionMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ShaftHubConnectionMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftHubConnections

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shafts(self: "Self") -> "List[_5612.ShaftMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ShaftMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Shafts

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def shafts_and_housings(
        self: "Self",
    ) -> "List[_5501.AbstractShaftOrHousingMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.AbstractShaftOrHousingMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ShaftsAndHousings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spiral_bevel_gear_sets(
        self: "Self",
    ) -> "List[_5618.SpiralBevelGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.SpiralBevelGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpiralBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def spring_dampers(
        self: "Self",
    ) -> "List[_5622.SpringDamperMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.SpringDamperMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpringDampers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_diff_gear_sets(
        self: "Self",
    ) -> "List[_5625.StraightBevelDiffGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.StraightBevelDiffGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelDiffGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def straight_bevel_gear_sets(
        self: "Self",
    ) -> "List[_5628.StraightBevelGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.StraightBevelGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StraightBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def synchronisers(
        self: "Self",
    ) -> "List[_5632.SynchroniserMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.SynchroniserMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Synchronisers

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def torque_converters(
        self: "Self",
    ) -> "List[_5637.TorqueConverterMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.TorqueConverterMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TorqueConverters

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def unbalanced_masses(
        self: "Self",
    ) -> "List[_5641.UnbalancedMassMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.UnbalancedMassMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UnbalancedMasses

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def worm_gear_sets(
        self: "Self",
    ) -> "List[_5646.WormGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.WormGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WormGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def zerol_bevel_gear_sets(
        self: "Self",
    ) -> "List[_5649.ZerolBevelGearSetMultibodyDynamicsAnalysis]":
        """List[mastapy._private.system_model.analyses_and_results.mbd_analyses.ZerolBevelGearSetMultibodyDynamicsAnalysis]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ZerolBevelGearSets

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_AssemblyMultibodyDynamicsAnalysis":
        """Cast to another type.

        Returns:
            _Cast_AssemblyMultibodyDynamicsAnalysis
        """
        return _Cast_AssemblyMultibodyDynamicsAnalysis(self)



"""BevelVirtualCylindricalGearSetISO10300MethodB2"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.gears.rating.virtual_cylindrical_gears import _405
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_BEVEL_VIRTUAL_CYLINDRICAL_GEAR_SET_ISO10300_METHOD_B2 = python_net_import(
    "SMT.MastaAPI.Gears.Rating.VirtualCylindricalGears",
    "BevelVirtualCylindricalGearSetISO10300MethodB2",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating.virtual_cylindrical_gears import _403

    Self = TypeVar("Self", bound="BevelVirtualCylindricalGearSetISO10300MethodB2")
    CastSelf = TypeVar(
        "CastSelf",
        bound="BevelVirtualCylindricalGearSetISO10300MethodB2._Cast_BevelVirtualCylindricalGearSetISO10300MethodB2",
    )


__docformat__ = "restructuredtext en"
__all__ = ("BevelVirtualCylindricalGearSetISO10300MethodB2",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_BevelVirtualCylindricalGearSetISO10300MethodB2:
    """Special nested class for casting BevelVirtualCylindricalGearSetISO10300MethodB2 to subclasses."""

    __parent__: "BevelVirtualCylindricalGearSetISO10300MethodB2"

    @property
    def virtual_cylindrical_gear_set_iso10300_method_b2(
        self: "CastSelf",
    ) -> "_405.VirtualCylindricalGearSetISO10300MethodB2":
        return self.__parent__._cast(_405.VirtualCylindricalGearSetISO10300MethodB2)

    @property
    def virtual_cylindrical_gear_set(
        self: "CastSelf",
    ) -> "_403.VirtualCylindricalGearSet":
        pass

        from mastapy._private.gears.rating.virtual_cylindrical_gears import _403

        return self.__parent__._cast(_403.VirtualCylindricalGearSet)

    @property
    def bevel_virtual_cylindrical_gear_set_iso10300_method_b2(
        self: "CastSelf",
    ) -> "BevelVirtualCylindricalGearSetISO10300MethodB2":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class BevelVirtualCylindricalGearSetISO10300MethodB2(
    _405.VirtualCylindricalGearSetISO10300MethodB2
):
    """BevelVirtualCylindricalGearSetISO10300MethodB2

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _BEVEL_VIRTUAL_CYLINDRICAL_GEAR_SET_ISO10300_METHOD_B2

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_BevelVirtualCylindricalGearSetISO10300MethodB2":
        """Cast to another type.

        Returns:
            _Cast_BevelVirtualCylindricalGearSetISO10300MethodB2
        """
        return _Cast_BevelVirtualCylindricalGearSetISO10300MethodB2(self)



"""CylindricalGearLTCAContactChartDataAsTextFile"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import utility
from mastapy._private.gears.cylindrical import _1250
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_LTCA_CONTACT_CHART_DATA_AS_TEXT_FILE = python_net_import(
    "SMT.MastaAPI.Gears.Cylindrical", "CylindricalGearLTCAContactChartDataAsTextFile"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="CylindricalGearLTCAContactChartDataAsTextFile")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearLTCAContactChartDataAsTextFile._Cast_CylindricalGearLTCAContactChartDataAsTextFile",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearLTCAContactChartDataAsTextFile",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearLTCAContactChartDataAsTextFile:
    """Special nested class for casting CylindricalGearLTCAContactChartDataAsTextFile to subclasses."""

    __parent__: "CylindricalGearLTCAContactChartDataAsTextFile"

    @property
    def gear_ltca_contact_chart_data_as_text_file(
        self: "CastSelf",
    ) -> "_1250.GearLTCAContactChartDataAsTextFile":
        return self.__parent__._cast(_1250.GearLTCAContactChartDataAsTextFile)

    @property
    def cylindrical_gear_ltca_contact_chart_data_as_text_file(
        self: "CastSelf",
    ) -> "CylindricalGearLTCAContactChartDataAsTextFile":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearLTCAContactChartDataAsTextFile(
    _1250.GearLTCAContactChartDataAsTextFile
):
    """CylindricalGearLTCAContactChartDataAsTextFile

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_LTCA_CONTACT_CHART_DATA_AS_TEXT_FILE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def coefficient_of_friction(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CoefficientOfFriction

        if temp is None:
            return ""

        return temp

    @property
    def gap_between_unloaded_flanks_transverse(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GapBetweenUnloadedFlanksTransverse

        if temp is None:
            return ""

        return temp

    @property
    def gear_a_depth_of_maximum_material_exposure_iso633642019(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearADepthOfMaximumMaterialExposureISO633642019

        if temp is None:
            return ""

        return temp

    @property
    def gear_a_maximum_material_exposure_iso633642019(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearAMaximumMaterialExposureISO633642019

        if temp is None:
            return ""

        return temp

    @property
    def gear_b_depth_of_maximum_material_exposure_iso633642019(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearBDepthOfMaximumMaterialExposureISO633642019

        if temp is None:
            return ""

        return temp

    @property
    def gear_b_maximum_material_exposure_iso633642019(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearBMaximumMaterialExposureISO633642019

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_contact_temperature_isotr1514412010(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingContactTemperatureISOTR1514412010

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_contact_temperature_isotr1514412014(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingContactTemperatureISOTR1514412014

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_contact_temperature_isots6336222018(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingContactTemperatureISOTS6336222018

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_flash_temperature_isotr1514412010(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingFlashTemperatureISOTR1514412010

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_flash_temperature_isotr1514412014(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingFlashTemperatureISOTR1514412014

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_flash_temperature_isots6336222018(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingFlashTemperatureISOTS6336222018

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_safety_factor_isotr1514412010(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingSafetyFactorISOTR1514412010

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_safety_factor_isotr1514412014(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingSafetyFactorISOTR1514412014

        if temp is None:
            return ""

        return temp

    @property
    def micropitting_safety_factor_isots6336222018(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingSafetyFactorISOTS6336222018

        if temp is None:
            return ""

        return temp

    @property
    def minimum_lubricant_film_thickness_isotr1514412010(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumLubricantFilmThicknessISOTR1514412010

        if temp is None:
            return ""

        return temp

    @property
    def minimum_lubricant_film_thickness_isotr1514412014(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumLubricantFilmThicknessISOTR1514412014

        if temp is None:
            return ""

        return temp

    @property
    def minimum_lubricant_film_thickness_isots6336222018(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumLubricantFilmThicknessISOTS6336222018

        if temp is None:
            return ""

        return temp

    @property
    def pressure_velocity_pv(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PressureVelocityPV

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_contact_temperature_agma925a03(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingContactTemperatureAGMA925A03

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_contact_temperature_agma925b22(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingContactTemperatureAGMA925B22

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_contact_temperature_din399041987(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingContactTemperatureDIN399041987

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_contact_temperature_isotr1398912000(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingContactTemperatureISOTR1398912000

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_contact_temperature_isots6336202017(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingContactTemperatureISOTS6336202017

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_contact_temperature_isots6336202022(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingContactTemperatureISOTS6336202022

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_flash_temperature_agma925a03(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingFlashTemperatureAGMA925A03

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_flash_temperature_agma925b22(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingFlashTemperatureAGMA925B22

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_flash_temperature_din399041987(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingFlashTemperatureDIN399041987

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_flash_temperature_isotr1398912000(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingFlashTemperatureISOTR1398912000

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_flash_temperature_isots6336202017(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingFlashTemperatureISOTS6336202017

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_flash_temperature_isots6336202022(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingFlashTemperatureISOTS6336202022

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_safety_factor_agma925a03(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorAGMA925A03

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_safety_factor_agma925b22(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorAGMA925B22

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_safety_factor_din399041987(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorDIN399041987

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_safety_factor_isotr1398912000(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorISOTR1398912000

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_safety_factor_isots6336202017(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorISOTS6336202017

        if temp is None:
            return ""

        return temp

    @property
    def scuffing_safety_factor_isots6336202022(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorISOTS6336202022

        if temp is None:
            return ""

        return temp

    @property
    def sliding_power_loss(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SlidingPowerLoss

        if temp is None:
            return ""

        return temp

    @property
    def sliding_velocity(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SlidingVelocity

        if temp is None:
            return ""

        return temp

    @property
    def specific_lubricant_film_thickness_isotr1514412010(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpecificLubricantFilmThicknessISOTR1514412010

        if temp is None:
            return ""

        return temp

    @property
    def specific_lubricant_film_thickness_isotr1514412014(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpecificLubricantFilmThicknessISOTR1514412014

        if temp is None:
            return ""

        return temp

    @property
    def specific_lubricant_film_thickness_isots6336222018(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SpecificLubricantFilmThicknessISOTS6336222018

        if temp is None:
            return ""

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearLTCAContactChartDataAsTextFile":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearLTCAContactChartDataAsTextFile
        """
        return _Cast_CylindricalGearLTCAContactChartDataAsTextFile(self)



"""ISO6336MetalRateableMesh"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.gears.rating.cylindrical.iso6336 import _534
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_ISO6336_METAL_RATEABLE_MESH = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336", "ISO6336MetalRateableMesh"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.rating.cylindrical import _482
    from mastapy._private.gears.rating import _378

    Self = TypeVar("Self", bound="ISO6336MetalRateableMesh")
    CastSelf = TypeVar(
        "CastSelf", bound="ISO6336MetalRateableMesh._Cast_ISO6336MetalRateableMesh"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ISO6336MetalRateableMesh",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ISO6336MetalRateableMesh:
    """Special nested class for casting ISO6336MetalRateableMesh to subclasses."""

    __parent__: "ISO6336MetalRateableMesh"

    @property
    def iso6336_rateable_mesh(self: "CastSelf") -> "_534.ISO6336RateableMesh":
        return self.__parent__._cast(_534.ISO6336RateableMesh)

    @property
    def cylindrical_rateable_mesh(self: "CastSelf") -> "_482.CylindricalRateableMesh":
        from mastapy._private.gears.rating.cylindrical import _482

        return self.__parent__._cast(_482.CylindricalRateableMesh)

    @property
    def rateable_mesh(self: "CastSelf") -> "_378.RateableMesh":
        from mastapy._private.gears.rating import _378

        return self.__parent__._cast(_378.RateableMesh)

    @property
    def iso6336_metal_rateable_mesh(self: "CastSelf") -> "ISO6336MetalRateableMesh":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ISO6336MetalRateableMesh(_534.ISO6336RateableMesh):
    """ISO6336MetalRateableMesh

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ISO6336_METAL_RATEABLE_MESH

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_ISO6336MetalRateableMesh":
        """Cast to another type.

        Returns:
            _Cast_ISO6336MetalRateableMesh
        """
        return _Cast_ISO6336MetalRateableMesh(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6819 import (
        AbstractAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6820 import (
        AbstractShaftCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6821 import (
        AbstractShaftOrHousingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6822 import (
        AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6823 import (
        AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6824 import (
        AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6825 import (
        AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6826 import (
        AssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6827 import (
        BearingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6828 import (
        BeltConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6829 import (
        BeltDriveCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6830 import (
        BevelDifferentialGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6831 import (
        BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6832 import (
        BevelDifferentialGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6833 import (
        BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6834 import (
        BevelDifferentialSunGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6835 import (
        BevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6836 import (
        BevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6837 import (
        BevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6838 import (
        BoltCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6839 import (
        BoltedJointCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6840 import (
        ClutchCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6841 import (
        ClutchConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6842 import (
        ClutchHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6843 import (
        CoaxialConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6844 import (
        ComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6845 import (
        ConceptCouplingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6846 import (
        ConceptCouplingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6847 import (
        ConceptCouplingHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6848 import (
        ConceptGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6849 import (
        ConceptGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6850 import (
        ConceptGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6851 import (
        ConicalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6852 import (
        ConicalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6853 import (
        ConicalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6854 import (
        ConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6855 import (
        ConnectorCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6856 import (
        CouplingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6857 import (
        CouplingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6858 import (
        CouplingHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6859 import (
        CVTBeltConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6860 import (
        CVTCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6861 import (
        CVTPulleyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6862 import (
        CycloidalAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6863 import (
        CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6864 import (
        CycloidalDiscCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6865 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6866 import (
        CylindricalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6867 import (
        CylindricalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6868 import (
        CylindricalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6869 import (
        CylindricalPlanetGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6870 import (
        DatumCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6871 import (
        ExternalCADModelCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6872 import (
        FaceGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6873 import (
        FaceGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6874 import (
        FaceGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6875 import (
        FEPartCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6876 import (
        FlexiblePinAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6877 import (
        GearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6878 import (
        GearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6879 import (
        GearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6880 import (
        GuideDxfModelCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6881 import (
        HypoidGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6882 import (
        HypoidGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6883 import (
        HypoidGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6884 import (
        InterMountableComponentConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6885 import (
        KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6886 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6887 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6888 import (
        KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6889 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6890 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6891 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6892 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6893 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6894 import (
        MassDiscCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6895 import (
        MeasurementComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6896 import (
        MicrophoneArrayCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6897 import (
        MicrophoneCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6898 import (
        MountableComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6899 import (
        OilSealCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6900 import (
        PartCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6901 import (
        PartToPartShearCouplingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6902 import (
        PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6903 import (
        PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6904 import (
        PlanetaryConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6905 import (
        PlanetaryGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6906 import (
        PlanetCarrierCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6907 import (
        PointLoadCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6908 import (
        PowerLoadCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6909 import (
        PulleyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6910 import (
        RingPinsCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6911 import (
        RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6912 import (
        RollingRingAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6913 import (
        RollingRingCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6914 import (
        RollingRingConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6915 import (
        RootAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6916 import (
        ShaftCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6917 import (
        ShaftHubConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6918 import (
        ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6919 import (
        SpecialisedAssemblyCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6920 import (
        SpiralBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6921 import (
        SpiralBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6922 import (
        SpiralBevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6923 import (
        SpringDamperCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6924 import (
        SpringDamperConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6925 import (
        SpringDamperHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6926 import (
        StraightBevelDiffGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6927 import (
        StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6928 import (
        StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6929 import (
        StraightBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6930 import (
        StraightBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6931 import (
        StraightBevelGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6932 import (
        StraightBevelPlanetGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6933 import (
        StraightBevelSunGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6934 import (
        SynchroniserCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6935 import (
        SynchroniserHalfCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6936 import (
        SynchroniserPartCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6937 import (
        SynchroniserSleeveCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6938 import (
        TorqueConverterCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6939 import (
        TorqueConverterConnectionCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6940 import (
        TorqueConverterPumpCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6941 import (
        TorqueConverterTurbineCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6942 import (
        UnbalancedMassCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6943 import (
        VirtualComponentCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6944 import (
        WormGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6945 import (
        WormGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6946 import (
        WormGearSetCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6947 import (
        ZerolBevelGearCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6948 import (
        ZerolBevelGearMeshCompoundCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses.compound._6949 import (
        ZerolBevelGearSetCompoundCriticalSpeedAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6819": [
            "AbstractAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6820": [
            "AbstractShaftCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6821": [
            "AbstractShaftOrHousingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6822": [
            "AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6823": [
            "AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6824": [
            "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6825": [
            "AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6826": [
            "AssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6827": [
            "BearingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6828": [
            "BeltConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6829": [
            "BeltDriveCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6830": [
            "BevelDifferentialGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6831": [
            "BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6832": [
            "BevelDifferentialGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6833": [
            "BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6834": [
            "BevelDifferentialSunGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6835": [
            "BevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6836": [
            "BevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6837": [
            "BevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6838": [
            "BoltCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6839": [
            "BoltedJointCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6840": [
            "ClutchCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6841": [
            "ClutchConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6842": [
            "ClutchHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6843": [
            "CoaxialConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6844": [
            "ComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6845": [
            "ConceptCouplingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6846": [
            "ConceptCouplingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6847": [
            "ConceptCouplingHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6848": [
            "ConceptGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6849": [
            "ConceptGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6850": [
            "ConceptGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6851": [
            "ConicalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6852": [
            "ConicalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6853": [
            "ConicalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6854": [
            "ConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6855": [
            "ConnectorCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6856": [
            "CouplingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6857": [
            "CouplingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6858": [
            "CouplingHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6859": [
            "CVTBeltConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6860": [
            "CVTCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6861": [
            "CVTPulleyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6862": [
            "CycloidalAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6863": [
            "CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6864": [
            "CycloidalDiscCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6865": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6866": [
            "CylindricalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6867": [
            "CylindricalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6868": [
            "CylindricalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6869": [
            "CylindricalPlanetGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6870": [
            "DatumCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6871": [
            "ExternalCADModelCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6872": [
            "FaceGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6873": [
            "FaceGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6874": [
            "FaceGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6875": [
            "FEPartCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6876": [
            "FlexiblePinAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6877": [
            "GearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6878": [
            "GearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6879": [
            "GearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6880": [
            "GuideDxfModelCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6881": [
            "HypoidGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6882": [
            "HypoidGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6883": [
            "HypoidGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6884": [
            "InterMountableComponentConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6885": [
            "KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6886": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6887": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6888": [
            "KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6889": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6890": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6891": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6892": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6893": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6894": [
            "MassDiscCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6895": [
            "MeasurementComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6896": [
            "MicrophoneArrayCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6897": [
            "MicrophoneCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6898": [
            "MountableComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6899": [
            "OilSealCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6900": [
            "PartCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6901": [
            "PartToPartShearCouplingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6902": [
            "PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6903": [
            "PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6904": [
            "PlanetaryConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6905": [
            "PlanetaryGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6906": [
            "PlanetCarrierCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6907": [
            "PointLoadCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6908": [
            "PowerLoadCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6909": [
            "PulleyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6910": [
            "RingPinsCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6911": [
            "RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6912": [
            "RollingRingAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6913": [
            "RollingRingCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6914": [
            "RollingRingConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6915": [
            "RootAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6916": [
            "ShaftCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6917": [
            "ShaftHubConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6918": [
            "ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6919": [
            "SpecialisedAssemblyCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6920": [
            "SpiralBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6921": [
            "SpiralBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6922": [
            "SpiralBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6923": [
            "SpringDamperCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6924": [
            "SpringDamperConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6925": [
            "SpringDamperHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6926": [
            "StraightBevelDiffGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6927": [
            "StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6928": [
            "StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6929": [
            "StraightBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6930": [
            "StraightBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6931": [
            "StraightBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6932": [
            "StraightBevelPlanetGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6933": [
            "StraightBevelSunGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6934": [
            "SynchroniserCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6935": [
            "SynchroniserHalfCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6936": [
            "SynchroniserPartCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6937": [
            "SynchroniserSleeveCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6938": [
            "TorqueConverterCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6939": [
            "TorqueConverterConnectionCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6940": [
            "TorqueConverterPumpCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6941": [
            "TorqueConverterTurbineCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6942": [
            "UnbalancedMassCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6943": [
            "VirtualComponentCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6944": [
            "WormGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6945": [
            "WormGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6946": [
            "WormGearSetCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6947": [
            "ZerolBevelGearCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6948": [
            "ZerolBevelGearMeshCompoundCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses.compound._6949": [
            "ZerolBevelGearSetCompoundCriticalSpeedAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundCriticalSpeedAnalysis",
    "AbstractShaftCompoundCriticalSpeedAnalysis",
    "AbstractShaftOrHousingCompoundCriticalSpeedAnalysis",
    "AbstractShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearCompoundCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearMeshCompoundCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearSetCompoundCriticalSpeedAnalysis",
    "AssemblyCompoundCriticalSpeedAnalysis",
    "BearingCompoundCriticalSpeedAnalysis",
    "BeltConnectionCompoundCriticalSpeedAnalysis",
    "BeltDriveCompoundCriticalSpeedAnalysis",
    "BevelDifferentialGearCompoundCriticalSpeedAnalysis",
    "BevelDifferentialGearMeshCompoundCriticalSpeedAnalysis",
    "BevelDifferentialGearSetCompoundCriticalSpeedAnalysis",
    "BevelDifferentialPlanetGearCompoundCriticalSpeedAnalysis",
    "BevelDifferentialSunGearCompoundCriticalSpeedAnalysis",
    "BevelGearCompoundCriticalSpeedAnalysis",
    "BevelGearMeshCompoundCriticalSpeedAnalysis",
    "BevelGearSetCompoundCriticalSpeedAnalysis",
    "BoltCompoundCriticalSpeedAnalysis",
    "BoltedJointCompoundCriticalSpeedAnalysis",
    "ClutchCompoundCriticalSpeedAnalysis",
    "ClutchConnectionCompoundCriticalSpeedAnalysis",
    "ClutchHalfCompoundCriticalSpeedAnalysis",
    "CoaxialConnectionCompoundCriticalSpeedAnalysis",
    "ComponentCompoundCriticalSpeedAnalysis",
    "ConceptCouplingCompoundCriticalSpeedAnalysis",
    "ConceptCouplingConnectionCompoundCriticalSpeedAnalysis",
    "ConceptCouplingHalfCompoundCriticalSpeedAnalysis",
    "ConceptGearCompoundCriticalSpeedAnalysis",
    "ConceptGearMeshCompoundCriticalSpeedAnalysis",
    "ConceptGearSetCompoundCriticalSpeedAnalysis",
    "ConicalGearCompoundCriticalSpeedAnalysis",
    "ConicalGearMeshCompoundCriticalSpeedAnalysis",
    "ConicalGearSetCompoundCriticalSpeedAnalysis",
    "ConnectionCompoundCriticalSpeedAnalysis",
    "ConnectorCompoundCriticalSpeedAnalysis",
    "CouplingCompoundCriticalSpeedAnalysis",
    "CouplingConnectionCompoundCriticalSpeedAnalysis",
    "CouplingHalfCompoundCriticalSpeedAnalysis",
    "CVTBeltConnectionCompoundCriticalSpeedAnalysis",
    "CVTCompoundCriticalSpeedAnalysis",
    "CVTPulleyCompoundCriticalSpeedAnalysis",
    "CycloidalAssemblyCompoundCriticalSpeedAnalysis",
    "CycloidalDiscCentralBearingConnectionCompoundCriticalSpeedAnalysis",
    "CycloidalDiscCompoundCriticalSpeedAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCompoundCriticalSpeedAnalysis",
    "CylindricalGearCompoundCriticalSpeedAnalysis",
    "CylindricalGearMeshCompoundCriticalSpeedAnalysis",
    "CylindricalGearSetCompoundCriticalSpeedAnalysis",
    "CylindricalPlanetGearCompoundCriticalSpeedAnalysis",
    "DatumCompoundCriticalSpeedAnalysis",
    "ExternalCADModelCompoundCriticalSpeedAnalysis",
    "FaceGearCompoundCriticalSpeedAnalysis",
    "FaceGearMeshCompoundCriticalSpeedAnalysis",
    "FaceGearSetCompoundCriticalSpeedAnalysis",
    "FEPartCompoundCriticalSpeedAnalysis",
    "FlexiblePinAssemblyCompoundCriticalSpeedAnalysis",
    "GearCompoundCriticalSpeedAnalysis",
    "GearMeshCompoundCriticalSpeedAnalysis",
    "GearSetCompoundCriticalSpeedAnalysis",
    "GuideDxfModelCompoundCriticalSpeedAnalysis",
    "HypoidGearCompoundCriticalSpeedAnalysis",
    "HypoidGearMeshCompoundCriticalSpeedAnalysis",
    "HypoidGearSetCompoundCriticalSpeedAnalysis",
    "InterMountableComponentConnectionCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundCriticalSpeedAnalysis",
    "MassDiscCompoundCriticalSpeedAnalysis",
    "MeasurementComponentCompoundCriticalSpeedAnalysis",
    "MicrophoneArrayCompoundCriticalSpeedAnalysis",
    "MicrophoneCompoundCriticalSpeedAnalysis",
    "MountableComponentCompoundCriticalSpeedAnalysis",
    "OilSealCompoundCriticalSpeedAnalysis",
    "PartCompoundCriticalSpeedAnalysis",
    "PartToPartShearCouplingCompoundCriticalSpeedAnalysis",
    "PartToPartShearCouplingConnectionCompoundCriticalSpeedAnalysis",
    "PartToPartShearCouplingHalfCompoundCriticalSpeedAnalysis",
    "PlanetaryConnectionCompoundCriticalSpeedAnalysis",
    "PlanetaryGearSetCompoundCriticalSpeedAnalysis",
    "PlanetCarrierCompoundCriticalSpeedAnalysis",
    "PointLoadCompoundCriticalSpeedAnalysis",
    "PowerLoadCompoundCriticalSpeedAnalysis",
    "PulleyCompoundCriticalSpeedAnalysis",
    "RingPinsCompoundCriticalSpeedAnalysis",
    "RingPinsToDiscConnectionCompoundCriticalSpeedAnalysis",
    "RollingRingAssemblyCompoundCriticalSpeedAnalysis",
    "RollingRingCompoundCriticalSpeedAnalysis",
    "RollingRingConnectionCompoundCriticalSpeedAnalysis",
    "RootAssemblyCompoundCriticalSpeedAnalysis",
    "ShaftCompoundCriticalSpeedAnalysis",
    "ShaftHubConnectionCompoundCriticalSpeedAnalysis",
    "ShaftToMountableComponentConnectionCompoundCriticalSpeedAnalysis",
    "SpecialisedAssemblyCompoundCriticalSpeedAnalysis",
    "SpiralBevelGearCompoundCriticalSpeedAnalysis",
    "SpiralBevelGearMeshCompoundCriticalSpeedAnalysis",
    "SpiralBevelGearSetCompoundCriticalSpeedAnalysis",
    "SpringDamperCompoundCriticalSpeedAnalysis",
    "SpringDamperConnectionCompoundCriticalSpeedAnalysis",
    "SpringDamperHalfCompoundCriticalSpeedAnalysis",
    "StraightBevelDiffGearCompoundCriticalSpeedAnalysis",
    "StraightBevelDiffGearMeshCompoundCriticalSpeedAnalysis",
    "StraightBevelDiffGearSetCompoundCriticalSpeedAnalysis",
    "StraightBevelGearCompoundCriticalSpeedAnalysis",
    "StraightBevelGearMeshCompoundCriticalSpeedAnalysis",
    "StraightBevelGearSetCompoundCriticalSpeedAnalysis",
    "StraightBevelPlanetGearCompoundCriticalSpeedAnalysis",
    "StraightBevelSunGearCompoundCriticalSpeedAnalysis",
    "SynchroniserCompoundCriticalSpeedAnalysis",
    "SynchroniserHalfCompoundCriticalSpeedAnalysis",
    "SynchroniserPartCompoundCriticalSpeedAnalysis",
    "SynchroniserSleeveCompoundCriticalSpeedAnalysis",
    "TorqueConverterCompoundCriticalSpeedAnalysis",
    "TorqueConverterConnectionCompoundCriticalSpeedAnalysis",
    "TorqueConverterPumpCompoundCriticalSpeedAnalysis",
    "TorqueConverterTurbineCompoundCriticalSpeedAnalysis",
    "UnbalancedMassCompoundCriticalSpeedAnalysis",
    "VirtualComponentCompoundCriticalSpeedAnalysis",
    "WormGearCompoundCriticalSpeedAnalysis",
    "WormGearMeshCompoundCriticalSpeedAnalysis",
    "WormGearSetCompoundCriticalSpeedAnalysis",
    "ZerolBevelGearCompoundCriticalSpeedAnalysis",
    "ZerolBevelGearMeshCompoundCriticalSpeedAnalysis",
    "ZerolBevelGearSetCompoundCriticalSpeedAnalysis",
)



"""AbstractForceAndDisplacementResults"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._math.vector_3d import Vector3D
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ABSTRACT_FORCE_AND_DISPLACEMENT_RESULTS = python_net_import(
    "SMT.MastaAPI.MathUtility.MeasuredVectors", "AbstractForceAndDisplacementResults"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.math_utility.measured_vectors import _1610, _1606, _1607

    Self = TypeVar("Self", bound="AbstractForceAndDisplacementResults")
    CastSelf = TypeVar(
        "CastSelf",
        bound="AbstractForceAndDisplacementResults._Cast_AbstractForceAndDisplacementResults",
    )


__docformat__ = "restructuredtext en"
__all__ = ("AbstractForceAndDisplacementResults",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_AbstractForceAndDisplacementResults:
    """Special nested class for casting AbstractForceAndDisplacementResults to subclasses."""

    __parent__: "AbstractForceAndDisplacementResults"

    @property
    def force_and_displacement_results(
        self: "CastSelf",
    ) -> "_1606.ForceAndDisplacementResults":
        from mastapy._private.math_utility.measured_vectors import _1606

        return self.__parent__._cast(_1606.ForceAndDisplacementResults)

    @property
    def force_results(self: "CastSelf") -> "_1607.ForceResults":
        from mastapy._private.math_utility.measured_vectors import _1607

        return self.__parent__._cast(_1607.ForceResults)

    @property
    def abstract_force_and_displacement_results(
        self: "CastSelf",
    ) -> "AbstractForceAndDisplacementResults":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class AbstractForceAndDisplacementResults(_0.APIBase):
    """AbstractForceAndDisplacementResults

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ABSTRACT_FORCE_AND_DISPLACEMENT_RESULTS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def node(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Node

        if temp is None:
            return ""

        return temp

    @property
    def force(self: "Self") -> "_1610.VectorWithLinearAndAngularComponents":
        """mastapy._private.math_utility.measured_vectors.VectorWithLinearAndAngularComponents

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Force

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def location(self: "Self") -> "Vector3D":
        """Vector3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Location

        if temp is None:
            return None

        value = conversion.pn_to_mp_vector3d(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_AbstractForceAndDisplacementResults":
        """Cast to another type.

        Returns:
            _Cast_AbstractForceAndDisplacementResults
        """
        return _Cast_AbstractForceAndDisplacementResults(self)
